Crate dstv

Crate dstv 

Modules

prelude
Re-export all the modules

Functions

get_f64_from_str
Get f64 from string and strips it of any non numeric characters
validate_flange
Validate if flange is either u v o or h other values are not allowed