pub enum ElementType {
    None,
    Header,
    OuterBorder,
    InnerBorder,
    PowderPointNotes,
    PunchPoint,
    Hole,
    Numeration,
    Bends,
    Cuts,
    EndOfFile,
}
Enum to represent the different types of elements in a DSTV file The enum is used to parse the DSTV file into a vector of DSTV elements The enum is also used to determine which DSTV elements to include in the final output

Variants



None

No element type, used for empty lines or lines that are not valid DSTV element identifiers



Header

The header of the DSTV file



OuterBorder

The outer border of the DSTV file



InnerBorder

The inner border of the DSTV file



PowderPointNotes

The powder point notes of the DSTV file



PunchPoint

The punch points of the DSTV file



Hole

The holes of the DSTV file



Numeration

The numeration of the DSTV file



Bends

The bends of the DSTV file



Cuts

The cuts of the DSTV file



EndOfFile

The end of file identifier of the DSTV file

Implementations

source

impl ElementType

source

pub fn from_str(element_type: &str) -> Self

Creates a new ElementType from a string slice

Arguments
  • element_type - A string slice that holds the element type
Returns
  • An ElementType
source

pub fn parse_dstv_element(&self, lines: &Vec<&str>) -> Vec<Box<dyn DstvElement>>

Parses a vector of string slices into a vector of DSTV elements

Arguments
  • lines - A vector of string slices that holds the lines of the DSTV file
Returns
  • A vector of DSTV elements