Header

Struct Header 

pub struct Header {
Show 25 fields pub order_identification: String, pub drawing_identification: String, pub phase_identification: String, pub piece_identification: String, pub steel_quality: String, pub quantity_of_pieces: i32, pub profile: String, pub code_profile: CodeProfile, pub length: f64, pub saw_length: Option<f64>, pub profile_height: f64, pub flange_width: f64, pub flange_thickness: f64, pub web_thickness: f64, pub radius: f64, pub weight_by_meter: f64, pub painting_surface_by_meter: f64, pub web_start_cut: f64, pub web_end_cut: f64, pub flange_start_cut: f64, pub flange_end_cut: f64, pub text1_info_on_piece: String, pub text2_info_on_piece: String, pub text3_info_on_piece: String, pub text4_info_on_piece: String,
}
The header of a DSTV file

Fields

order_identification: String

The order identification of the order the pieces belong to

drawing_identification: String

The drawing identification of the drawing the pieces belong to

phase_identification: String

The phase identification of the phase the pieces belong to

piece_identification: String

The piece identification of the piece

steel_quality: String

The steel quality of the piece

quantity_of_pieces: i32

The number of pieces for the order, and phase

profile: String

The profile of the piece

code_profile: CodeProfile

The profile type of the piece

length: f64

The length of the piece

saw_length: Option<f64>

The saw length of the piece

profile_height: f64

The profile height of the piece

flange_width: f64

The flange width of the piece

flange_thickness: f64

The flange thickness of the piece

web_thickness: f64

The web thickness of the piece

radius: f64

The radius of the piece

weight_by_meter: f64

The weight by meter of the piece

painting_surface_by_meter: f64

The painting surface by meter of the piece

web_start_cut: f64

The web start cut of the piece

web_end_cut: f64

The web end cut of the piece

flange_start_cut: f64

The flange start cut of the piece

flange_end_cut: f64

The flange end cut of the piece

text1_info_on_piece: String

The text1 info on piece of the piece

text2_info_on_piece: String

The text2 info on piece of the piece

text3_info_on_piece: String

The text3 info on piece of the piece

text4_info_on_piece: String

The text4 info on piece of the piece

Implementations

Source

impl Header

pub fn from_lines(lines: Vec<&str>) -> Result<Self, ParseDstvError>

Creates a new Header from a vector of string slices

Arguments
  • lines - A vector of string slices that holds the header
Returns

A Result containing either a Header or an error message