pub struct Header {Show 25 fields
pub order_identification: String,
pub drawing_identification: String,
pub phase_identification: String,
pub piece_identification: String,
pub steel_quality: String,
pub quantity_of_pieces: i32,
pub profile: String,
pub code_profile: CodeProfile,
pub length: f64,
pub saw_length: Option<f64>,
pub profile_height: f64,
pub flange_width: f64,
pub flange_thickness: f64,
pub web_thickness: f64,
pub radius: f64,
pub weight_by_meter: f64,
pub painting_surface_by_meter: f64,
pub web_start_cut: f64,
pub web_end_cut: f64,
pub flange_start_cut: f64,
pub flange_end_cut: f64,
pub text1_info_on_piece: String,
pub text2_info_on_piece: String,
pub text3_info_on_piece: String,
pub text4_info_on_piece: String,
}Expand description
The header of a DSTV file
Fields
order_identification: StringThe order identification of the order the pieces belong to
drawing_identification: StringThe drawing identification of the drawing the pieces belong to
phase_identification: StringThe phase identification of the phase the pieces belong to
piece_identification: StringThe piece identification of the piece
steel_quality: StringThe steel quality of the piece
quantity_of_pieces: i32The number of pieces for the order, and phase
profile: StringThe profile of the piece
code_profile: CodeProfileThe profile type of the piece
length: f64The length of the piece
saw_length: Option<f64>The saw length of the piece
profile_height: f64The profile height of the piece
flange_width: f64The flange width of the piece
flange_thickness: f64The flange thickness of the piece
web_thickness: f64The web thickness of the piece
radius: f64The radius of the piece
weight_by_meter: f64The weight by meter of the piece
painting_surface_by_meter: f64The painting surface by meter of the piece
web_start_cut: f64The web start cut of the piece
web_end_cut: f64The web end cut of the piece
flange_start_cut: f64The flange start cut of the piece
flange_end_cut: f64The flange end cut of the piece
text1_info_on_piece: StringThe text1 info on piece of the piece
text2_info_on_piece: StringThe text2 info on piece of the piece
text3_info_on_piece: StringThe text3 info on piece of the piece
text4_info_on_piece: StringThe text4 info on piece of the piece